(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     14976,        357]
NotebookOptionsPosition[     13177,        321]
NotebookOutlinePosition[     13787,        344]
CellTagsIndexPosition[     13744,        341]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 2, Section 2.6, Figure 2.10", "Section",ExpressionUUID->"594e751c-3913-4ddd-9290-ce54105eb095"],

Cell[TextData[{
 "In order to illustrate the guiding centre motion we need to draw a small \
2:1 centred ellipse at different points on a circle (the path of the guiding \
centre) as well as the location of the particle on the 2:1 ellipse and the \
keplerian elliptical path.  First set the eccentricity of orbit to be ",
 StyleBox["ecc=0.2", "Input"],
 ". "
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9bb9df89-fed7-4edf-a426-790e78193448"],

Cell["ecc=0.2;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"672ffb20-8be3-4914-92b5-727058a04ea7"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["ellipse", "Input"],
 " that will draw a dashed-line, 2:1 centred ellipse with centre ",
 StyleBox["(xc,yc)", "Input"],
 ", of eccentricity ",
 StyleBox["ec", "Input"],
 " rotated at an angle ",
 StyleBox["\[Theta]", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.81115509407066*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"584e63c8-9b48-4b29-9059-0bce04164b66"],

Cell["\<\
ellipse[{xc_,yc_},ec_,\[Theta]_] :=
  Module[{\[Phi],rot},
   rot = {{Cos[\[Theta]], -Sin[\[Theta]]},
          {Sin[\[Theta]],  Cos[\[Theta]]}};
   pointlist = {};
   Do[AppendTo[pointlist,
         {xc,yc} + rot.{ec*Cos[\[Phi]], 2*ec*Sin[\[Phi]]}],
      {\[Phi],0,2Pi,Pi/10}];
   Graphics[{Dashing[{0.01, 0.01}],
             Line[pointlist]}]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"af7feb28-1766-4776-b276-bcb87e9c6ff6"],

Cell["\<\
Create a graphics object for a dashed-line circle to show the path of the \
epicentre ...\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3364f61f-ff23-4816-bfef-f3b530dfdf85"],

Cell["\<\
c = Graphics[{Point[{-2*ecc,0}],
      Dashing[{0.01, 0.01}],Circle[{0,0},1]}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"b469890e-19aa-4d9e-ae27-31c77fb7240b"],

Cell["\<\
... and one to show the elliptical keplerian path of the particle.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"490adaf7-5a10-4b29-a80b-1cf9009a48ef"],

Cell["\<\
e = Graphics[{Disk[{0,0},0.1],
      Circle[{-ecc,0},{1,Sqrt[1-ecc^2]}]}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"ca025997-bde9-401c-91ea-d5cd87fb4d65"],

Cell[TextData[{
 "Now set up a loop to draw the circle, ellipse and the epicycle together \
with suitable lines.  Each plot is stored in an array ",
 StyleBox["p", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e4e9ba77-0e10-42ce-90a5-013da8b3715f"],

Cell["\<\
Do[
  m = i*Pi/3;
  cm = Cos[m];
  sm = Sin[m];
  f  = m + 2 * ecc * sm;
  r = (1-ecc^2)/(1+ecc*Cos[f]);
  xp = r * Cos[f];  yp = r * Sin[f];
  xe = cm;  ye = sm;
  p[i]=
  Show[c,e,ellipse[{xe,ye},ecc,m],
       Graphics[{Disk[{xp,yp},0.05]}],
       Graphics[{Line[{{0,0},{xe,ye}}],
                 Line[{{xe,ye},{xp,yp}}],
                 Line[{{-2*ecc,0},{xp,yp}}],
                 Line[{{xp,yp},{0,0}}]}
      ],
   AspectRatio->Automatic,
   PlotRange->{{-1.4,1.4},{-1.4,1.4}}],
  {i,0,5}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"4151f02b-785c-4d58-9b1b-4110d1de6aeb"],

Cell[TextData[{
 "Now display the content of ",
 StyleBox["p", "Input"],
 " as a graphics array."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cde195c3-3199-4753-b295-95d0b0217476"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsGrid[
  {{p[0],p[1],p[2]},
   {p[3],p[4],p[5]}}]]\
\>", "Input",
 CellChangeTimes->{{3.81115523047932*^9, 3.811155233312298*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"9db39f6e-9acd-48a6-853a-73003c94bb29"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGn+0ZoGCz9VtGae7P9lJOzz5uXLLfftVpDc39
0z7ZG2gpsVtInLNfrFTU0Pzwo31IrJvnz61X7AWN+vtV/36wn3k3k/9GxA2o
OR/sZ80EgZv292Y/fLCF9R1cftcu6f8/bN7A9a/OWLe28dIruPmzOlT/nHz5
Em4/xJyXcPehye9H078fzfz9aPbvR3PffjT370fz3340/+9HC5/96OEHAEdn
nRg=
          "]]}, 
        DiskBox[{0.8, 0.}, 0.05], {LineBox[{{0, 0}, {1, 0}}], 
         LineBox[{{1, 0}, {0.8, 0.}}], LineBox[{{-0.4, 0}, {0.8, 0.}}], 
         LineBox[{{0.8, 0.}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {193.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGj+1nHmdU3bDgg/1phrTX0Tb37Vki05bLVH+0
DznWx1KhesM+b4X4hK2/PtrP9JRUTbp80V7Bhzf9r9An+7R9Pcx/Tpy0v/NB
fefkgx/t97xe+unKisP2HZHxywv4Ptrf0xVuP3//oL3pZS5jWe4P9lJ1C91W
zDpiv1/fcvn3hW/tQ/Sv7/825bQ962XPTTP+vrL/J7jx8Xv+y/YT1iscCMp+
YT9rJgjctFfiWts2VfuZ/ez/PlyXEh/Y+zx/3Lin7In9tTk7/jq/fWxf6dG4
oav8sb1JdPFbP7Hn9qKM05h+uz22T7sg8/9A70v7udsT4s69fGwv2Bp2+JTo
a3uXZx8bRQKe2neYWMvxdLy2f/VpVtbusOf2VQvC34XefGU/NbNc89+pl/ba
JlwBh6Re2vsfS5OLzX9jz1iuzsdR8cz+yMt+gcWM7+3Rww8A+f6o4g==
          "]]}, 
        DiskBox[{0.16345034259368624, 0.9127911560317566}, 0.05], {
         LineBox[NCache[{{0, 0}, {
            Rational[1, 2], Rational[1, 2] 3^Rational[1, 2]}}, {{0, 0}, {0.5, 
            0.8660254037844386}}]], 
         LineBox[NCache[{{Rational[1, 2], Rational[1, 2] 3^Rational[1, 2]}, {
            0.16345034259368624`, 0.9127911560317566}}, {{0.5, 
           0.8660254037844386}, {0.16345034259368624`, 0.9127911560317566}}]],
          LineBox[{{-0.4, 0}, {0.16345034259368624`, 0.9127911560317566}}], 
         LineBox[{{0.16345034259368624`, 0.9127911560317566}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {580.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGj/fPPM6oumHBB3vGcnU+jopn+4+87BdYzPje
XtuEK+CQ1Mv9/sfS5GLz39hXLQh/F3rz1f6pmeWa/069tO8wsZbj6Xi9/9Wn
WVm7w57bC7aGHT4l+nq/y7OPjSIBT+3TLsj8P9D7cv/c7Qlx514+tjeJLn7r
J/Z8vyjjNKbfbo/tr83Z8df57eP9lR6NG7rKH9vP/u/DdSnxwX6f548b95Q9
sZ81EwRu7lfiWts2VfuZ/T/BjY/f81/eP2G9woGg7Bf2IfrX93+bcno/62XP
TTP+vrKXqlvotmLWkf379S2Xf1/41v6ernD7+fsH95te5jKW5f5gv+f10k9X
Vhze3xEZv7yA76N92r4e5j8nTu6/80F95+SDH+1nekqqJl2+uF/Bhzf9r9An
+5BjfSwVqjf2560Qn7D110f70wxpr6Nt7u9niUxbLlP90R49/ACXWLNi
          "]]}, 
        DiskBox[{-0.8661700817890328, 0.7307316369530099}, 0.05], {
         LineBox[NCache[{{0, 0}, {
            Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2]}}, {{0, 
            0}, {-0.5, 0.8660254037844386}}]], 
         LineBox[NCache[{{
            Rational[-1, 2], Rational[1, 2] 
             3^Rational[1, 2]}, {-0.8661700817890328, 
            0.7307316369530099}}, {{-0.5, 
           0.8660254037844386}, {-0.8661700817890328, 0.7307316369530099}}]], 
         LineBox[{{-0.4, 0}, {-0.8661700817890328, 0.7307316369530099}}], 
         LineBox[{{-0.8661700817890328, 0.7307316369530099}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {967.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}]}, {InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGn/czQMFm67eM0tyf90s5Pfu4ccn+/atOa2ju
n/Zpv4GWEruFxLn9i5WKGpofftwfEuvm+XPrlf2CRv39qn8/7J95N5P/RsQN
qDkf9s+aCQI399+b/fDBFtZ3cPldu6T//7B5A9e/OmPd2sZLr+Dmz+pQ/XPy
5Uu4/RBzXsLdhyZvj6bfHs18ezT77dHcZ4/mfns0/9mj+d8eLXzs0cMPAAZ9
p5g=
          "]]}, 
        DiskBox[{-1.2, 1.4695761589768238*^-16}, 0.05], {
         LineBox[{{0, 0}, {-1, 0}}], 
         LineBox[{{-1, 0}, {-1.2, 1.4695761589768238`*^-16}}], 
         LineBox[{{-0.4, 0}, {-1.2, 1.4695761589768238`*^-16}}], 
         LineBox[{{-1.2, 1.4695761589768238`*^-16}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {193.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGj/fPPM6oumHBh/2nGdJeR9vc388SmbZcpvrj
/pBjfSwVqjf2560Qn7D118f9Mz0lVZMuX9yv4MOb/lfo0/60fT3Mf06c3H/n
g/rOyQc/7t/zeumnKysO7++IjF9ewPdx/z1d4fbz9w/uN73MZSzL/WG/VN1C
txWzjuzfr2+5/PvCt/tD9K/v/zbl9H7Wy56bZvx9tf+f4MbH7/kv75+wXuFA
UPaL/bNmgsDN/Upca9umaj/bP/u/D9elxAf7fZ4/btxT9mT/tTk7/jq/fby/
0qNxQ1f54/0m0cVv/cSe7xdlnMb02+3x/rQLMv8P9L7cP3d7Qty5l4/3C7aG
HT4l+nq/y7OPjSIBT/d3mFjL8XS83v/q06ys3WHP91ctCH8XevPV/qmZ5Zr/
Tr3cr23CFXBI6uV+/2NpcrH5b/YzlqvzcVQ823/kZb/AYsb3+9HDDwCD0L3i

          "]]}, 
        DiskBox[{-0.8661700817890335, -0.7307316369530095}, 0.05], {
         LineBox[NCache[{{0, 0}, {
            Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2]}}, {{0, 
            0}, {-0.5, -0.8660254037844386}}]], 
         LineBox[NCache[{{
            Rational[-1, 2], Rational[-1, 2] 
             3^Rational[
               1, 2]}, {-0.8661700817890335, -0.7307316369530095}}, {{-0.5, \
-0.8660254037844386}, {-0.8661700817890335, -0.7307316369530095}}]], 
         LineBox[{{-0.4, 0}, {-0.8661700817890335, -0.7307316369530095}}], 
         LineBox[{{-0.8661700817890335, -0.7307316369530095}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {580.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{{PointBox[{-0.4, 0}], 
         {Dashing[{0.01, 0.01}], CircleBox[{0, 0}, 1]}}, {
         DiskBox[{0, 0}, 0.1], 
         CircleBox[{-0.2, 0}, {1., 0.9797958971132712}]}, 
        {Dashing[{0.01, 0.01}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGj+1nHmdU3bDgw37GcnU+jopn9kde9gssZny/
X9uEK+CQ1Et7/2NpcrH5b/ZXLQh/F3rzlf3UzHLNf6de7u8wsZbj6Xht/+rT
rKzdYc/3C7aGHT4l+tre5dnHRpGAp/vTLsj8P9D70n7u9oS4cy8f7zeJLn7r
J/bcXpRxGtNvt8f7r83Z8df57WP7So/GDV3lj/fP/u/DdSnxgb3P88eNe8qe
7J81EwRu2itxrW2bqv1s/z/BjY/f81+2n7Be4UBQ9ov9IfrX93+bctqe9bLn
phl/X+2XqlvotmLWEfv9+pbLvy98u/+ernD7+fsH7U0vcxnLcn/Yv+f10k9X
Vhy274iMX17A93F/2r4e5j8nTtrf+aC+c/LBj/tnekqqJl2+aK/gw5v+V+jT
/pBjfSwVqjfs81aIT9j66+P+0wxpr6Nt7tuzRKYtl6n+uB89/ABDWLNi
          "]]}, 
        DiskBox[{0.16345034259368643, -0.9127911560317565}, 0.05], {
         LineBox[NCache[{{0, 0}, {
            Rational[1, 2], Rational[-1, 2] 3^Rational[1, 2]}}, {{0, 0}, {
            0.5, -0.8660254037844386}}]], 
         LineBox[NCache[{{Rational[1, 2], Rational[-1, 2] 3^Rational[1, 2]}, {
            0.16345034259368643`, -0.9127911560317565}}, {{
           0.5, -0.8660254037844386}, {
           0.16345034259368643`, -0.9127911560317565}}]], 
         LineBox[{{-0.4, 0}, {0.16345034259368643`, -0.9127911560317565}}], 
         LineBox[{{0.16345034259368643`, -0.9127911560317565}, {0, 0}}]}},
       AspectRatio->Automatic,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-1.4, 1.4}, {-1.4, 1.4}}], {967.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}]}}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[700]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.81115516367124*^9, {3.811155234778933*^9, 3.8111552595063133`*^9}},
 CellLabel->"Out[14]=",ExpressionUUID->"edc89d78-9d5b-4b20-b899-0dec4a246d3f"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{916, 713},
WindowMargins->{{18, Automatic}, {Automatic, 281}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"f834d251-5caf-4ce4-871a-a2a09500e470"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 109, 0, 67, "Section",ExpressionUUID->"594e751c-3913-4ddd-9290-ce54105eb095"],
Cell[670, 22, 480, 10, 95, "Text",ExpressionUUID->"9bb9df89-fed7-4edf-a426-790e78193448"],
Cell[1153, 34, 135, 2, 30, "Input",ExpressionUUID->"672ffb20-8be3-4914-92b5-727058a04ea7"],
Cell[1291, 38, 447, 14, 76, "Text",ExpressionUUID->"584e63c8-9b48-4b29-9059-0bce04164b66"],
Cell[1741, 54, 484, 13, 192, "Input",ExpressionUUID->"af7feb28-1766-4776-b276-bcb87e9c6ff6"],
Cell[2228, 69, 223, 6, 53, "Text",ExpressionUUID->"3364f61f-ff23-4816-bfef-f3b530dfdf85"],
Cell[2454, 77, 215, 5, 48, "Input",ExpressionUUID->"b469890e-19aa-4d9e-ae27-31c77fb7240b"],
Cell[2672, 84, 200, 5, 53, "Text",ExpressionUUID->"490adaf7-5a10-4b29-a80b-1cf9009a48ef"],
Cell[2875, 91, 210, 5, 48, "Input",ExpressionUUID->"ca025997-bde9-401c-91ea-d5cd87fb4d65"],
Cell[3088, 98, 300, 8, 53, "Text",ExpressionUUID->"e4e9ba77-0e10-42ce-90a5-013da8b3715f"],
Cell[3391, 108, 634, 22, 354, "Input",ExpressionUUID->"4151f02b-785c-4d58-9b1b-4110d1de6aeb"],
Cell[4028, 132, 219, 7, 53, "Text",ExpressionUUID->"cde195c3-3199-4753-b295-95d0b0217476"],
Cell[CellGroupData[{
Cell[4272, 143, 263, 7, 66, "Input",ExpressionUUID->"9db39f6e-9acd-48a6-853a-73003c94bb29"],
Cell[4538, 152, 8623, 166, 434, "Output",ExpressionUUID->"edc89d78-9d5b-4b20-b899-0dec4a246d3f"]
}, Open  ]]
}
]
*)

